import subprocess
import pathlib
import os
import shutil
import yaml
import json


def binary_constructor(loader: yaml.SafeLoader, node: yaml.nodes.MappingNode) -> str:
    """Construct an employee."""
    return str(node.value)


def get_loader():
    """Add constructors to PyYAML loader."""
    loader = yaml.SafeLoader
    loader.add_constructor("!binary", binary_constructor)
    return loader


def get_repo_height() -> int:
    git_branch_height = subprocess.run(['git', 'rev-list', '--count', 'HEAD'], stdout=subprocess.PIPE)

    return int(git_branch_height.stdout.decode('utf-8').strip())


def build(kwargs):
    input_data = pathlib.Path(os.path.dirname(__file__)).joinpath('../../_data/').resolve()
    if input_data.exists():
        output_data = pathlib.Path(os.path.dirname(__file__)).joinpath('./share')
        if not pathlib.Path(output_data).exists():
            os.mkdir(output_data)

        for file in input_data.rglob('**/*.yaml'):
            try:
                input_file = pathlib.Path(file).relative_to(input_data)
                output_file = output_data.joinpath(input_file.with_suffix('.json'))

                print(f"Copying {input_file} to {output_file}")
                # Read YAML file
                with open(file, 'r') as stream:
                    data_loaded = yaml.load(stream, Loader=get_loader())

                    output_file.parent.mkdir(parents=True, exist_ok=True)

                    with open(output_file, 'w') as outfile:
                        json.dump(data_loaded, outfile, indent=4)
            except Exception as e:
                print(f"Error handling {file}:\n\n{e}")
                raise e



import pathlib
import os
import json
from typing import Dict, Any

DATA_PATH = pathlib.Path(os.path.dirname(__file__)).joinpath('../share/')


def load_file(name: str) -> Dict[str, Any]:
    if name.endswith('.yaml'):
        name = name[:-5]

    if name.endswith('.yml'):
        name = name[:-4]

    if not name.endswith('.json'):
        name = f"{name}.json"

    data_path = DATA_PATH.joinpath(name)
    return json.loads(data_path.read_text())


def get_data(name: str) -> Dict[str, Any]:
    return load_file(name)


def get_url(name: str, fmt=None) -> str:
    fmt = 'json' if fmt is None else fmt
    return f"https://docs.hackdiff.rent/.data/{name}.{fmt}"



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['apple_data']

package_data = \
{'': ['*']}

setup_kwargs = {
    'name': 'apple-data',
    'version': '1.0.517',
    'description': 'Static data from https://docs.hackdiffe.rent',
    'long_description': "# Apple Hardware Data\n\nBrought to you by the [Hack Different](https://hackdifferent.com) team.\n\n## Introduction\n\nThis is a package with data files sourced from\nthe [hack-different/apple-knowledge](https://github.com/hack-different/apple-knowledge/tree/main/_data)\nrepository.  Updates to that repository will automatically update this package, therefore no attempt should\nbe made to update the data files by any other method.\n\n## Accessing the Data\n\nFor the time being, there is only one simple API:\n\n```python\nfrom apple_data import get_data\n\nREGISERS = get_data('registers')\n```\n\n## Credits\n\n* [Hack Different](https://hackdifferent.com)\n\nCreated and maintained as a labor of love by [`rickmark`](https://github.com/rickmark)",
    'author': 'Rick Mark',
    'author_email': 'rickmark@outlook.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'python_requires': '>=3.8,<4.0',
}
from build import *
build(setup_kwargs)

setup(**setup_kwargs)
